@@ -24,7 +24,7 @@ pub fn env_staging() -> TunnelServiceProperties {
 pub fn env_development() -> TunnelServiceProperties {
     TunnelServiceProperties {
         service_uri: format!("https://{}", DEV_DNS_NAME),
-        service_app_id: NON_PROD_FIRST_PARTY_APP_ID.to_owned(),
+        service_app_id: DEV_FIRST_PARTY_APP_ID.to_owned(),
         service_internal_app_id: DEV_THIRD_PARTY_APP_ID.to_owned(),
         github_app_client_id: NON_PROD_GITHUB_APP_CLIENT_ID.to_owned(),
     }
